# galaxies_extended.dsc
#
# Extended galaxy Deep Space Catalog for Celestia
#
# Version 1.01
#  - converted to .DSC format for Celestia v1.3 by s.ball 24feb03 
#  - deleted globular clusters (now in the separate globular_clusters.dsc)
#  - deleted galaxies that are included with Celestia
#
# version 1.00
#  - Added version number
#  - Added galaxies out to NGC 4151
#  - Added Messier designations to globular clusters
# 
# An extension of the original galaxies.dat
# Modified by Paul Baulch (pbaulch@au.infogrames.com)
# Modified by s.ball (seb+cel@lns.cornell.edu) 24feb03
#
# What to do with this file as of v1.01:
# 1) Copy this file to Celestia/extras/ or your personal extras directory
# 2) Run Celestia, and you should see more of the Universe!
#
# Current contents:
#
#  863 galaxies (M104 currently represented with two objects)
#  (globular clusters moved to separate .DSC file)

# v1.00 Notes:
#
#  Tully's catalogue places gives identical distance values for almost all members
#  of some galaxy clusters (e.g. 54.8Mly for Virgo), which gives a very unrealistic
#  result when used directly, in that all galaxies in the cluster are located in a plane.
#
#  I have added 'random' variations along the terrestrial line-of-sight of up
#  to +/- R, where R is the approximate radius of the cluster, using a methodology which:
#  A) pays attention to interacting galaxies
#  B) gives the cluster a spherical shape
#  C) places spirals toward the exterior and ellipticals toward the interior
#  D) assumes slightly brighter/larger galaxies are nearer, and vice versa.
#
#  This methodology has been applied to the following clusters/groups:
#	Virgo
#	Ursa Major I/II
#	Coma Berenices
#	Fornax
#
#  This should give a result which would be, relatively speaking, more accurate
#  than that represented by Tully's raw estimates, and certainly looks better.
#

#############################################################################
#
#  Local Group of galaxies
#


# NGC 6822, Barnard's Galaxy
Galaxy "@NGC 6822"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+6822"
	Type "E3"
	RA 19.74
	Dec -14.76
	Distance 1.7e6
	Radius 15000
}

# NGC 185, remote satellite of M31
Galaxy "@NGC 185"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+185"
	Type "E3"
	RA 0.666
	Dec 48.333
	Distance 2.5e6
	Radius 10000
	Detail 0.5
}

# NGC 147, remote satellite of M31
Galaxy "@NGC 147"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+147"
	Type "E5"
	RA 0.369
	Dec 48.517
	Distance 2.4e6
	Radius 10500
	Detail 0.5
	Axis [ -0.596 -0.191 0.780 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+147"
}

# IC 10 / UGC 192
Galaxy "@IC 10"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=IC+10"
	Type "Irr"
	RA 0.295
	Dec 59.017
	Distance 2.0e6
	Radius 10000
	Detail 0.5
}

# IC 1613 / UGC 668
Galaxy "@IC 1613"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=IC+1613"
	Type "Irr"
	RA 1.079
	Dec 2.12
	Distance 2.3e6
	Radius 10000
	Detail 0.5
}

# UGC 5364
Galaxy "@UGC 5364"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+5364"
	Type "Irr"
	RA 9.988
	Dec 30.74
	Distance 3.3e6
	Radius 5000
	Detail 0.5
}

# UGC 12613
Galaxy "@UGC 12613"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+12613"
	Type "Irr"
	RA 23.475
	Dec 14.74
	Distance 3.3e6
	Radius 10000
	Detail 0.5
}

#############################################################################
#
#  Miscellaneous dwarf galaxies near the Local Group
#

# NGC 3109, outlying dwarf galaxy
Galaxy "@NGC 3109"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3109"
	Type "Irr"
	RA 10.052
	Dec -26.15
	Distance 4.0e6
	Radius 20000
}

# UGC 6456
Galaxy "@UGC 6456"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+6456"
	Type "Irr"
	RA 11.466
	Dec 78.99
	Distance 4.6e6
	Radius 5000
}

# UGC 5373
Galaxy "@UGC 5373"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+5373"
	Type "Irr"
	RA 10.0
	Dec 5.33
	Distance 5.2e6
	Radius 10000
}

# UGC 8091
Galaxy "@UGC 8091"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+8091"
	Type "Irr"
	RA 12.978
	Dec 14.21
	Distance 5.5e6
	Radius 10000
}

# UGC 4459
Galaxy "@UGC 4459"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+4459"
	Type "Irr"
	RA 8.567
	Dec 66.16
	Distance 6.5e6
	Radius 10000
}

# UGC 3974
Galaxy "@UGC 3974"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+3974"
	Type "Irr"
	RA 7.698
	Dec 16.8
	Distance 6.8e6
	Radius 10000
}

# IC 2574 / UGC 5666
Galaxy "@IC 2574"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=IC+2574"
	Type "Irr"
	RA 10.474
	Dec 68.41
	Distance 8.8e6
	Radius 15000
}

# UGC 4115
Galaxy "@UGC 4115"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+4115"
	Type "Irr"
	RA 7.95
	Dec 14.38
	Distance 1.04e7
	Radius 5000
}

#############################################################################
#
#  Ursa Major Group of galaxies
#


# M82 / NGC 3034
Galaxy "@M82"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+82"
	Type "E6"
	RA 9.93
	Dec 69.683
	Distance 1.2e7
	Radius 20000
}

# NGC 3077
Galaxy "@NGC 3077"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3077"
	Type "E2"
	RA 10.055
	Dec 68.733
	Distance 1.2e7
	Radius 10000
}

# NGC 2976
Galaxy "@NGC 2976"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+2976"
	Type "Sc"
	RA 9.788
	Dec 67.917
	Distance 1.2e7
	Radius 30000
}

# NGC 2403, outlying member?
Galaxy "@NGC 2403"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+2403"
	Type "Sc"
	RA 7.615
	Dec 65.6
	Distance 1.2e7
	Radius 30000
}

# Holmberg I / UGC 5139, outlying member?
Galaxy "@Holmberg I"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Holmberg+I"
	Type "Irr"
	RA 9.674
	Dec 71.19
	Distance 1.43e7
	Radius 10000
}

# Arp 268 / UGC 4305, outlying member?
Galaxy "@Arp 268"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=ARP+268"
	Type "Irr"
	RA 8.322
	Dec 70.71
	Distance 1.47e7
	Radius 20000
}

#############################################################################
#
#  Maffei Group of galaxies
#

# Maffei I
Galaxy "@Maffei I"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Maffei+I"
	Type "E4"
	RA 2.605
	Dec 59.65
	Distance 1.44e7
	Radius 60000
}

# Maffei II
Galaxy "@Maffei II"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Maffei+II"
	Type "SBa"
	RA 2.698
	Dec 59.6
	Distance 1.2e7
	Radius 40000
}

# Dwingeloo 1
Galaxy "@Dwingeloo 1"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=Dwingeloo 1"
	Type "SB"
	RA 2.948
	Dec 58.917
	Distance 1.63e7
	Radius 50000
}

# IC 342 = UGC 2847
Galaxy "@IC 342"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=IC+342"
	Type "Sc"
	RA 3.782
	Dec 68.083
	Distance 1.2e7
	Radius 50000
	Axis [ 0.712 0.533 0.456 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=IC+342"
	Angle 100
}

# NGC 1560
Galaxy "@NGC 1560"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+1560"
	Type "Sc"
	RA 4.547
	Dec 71.883
	Distance 9.6e6
	Radius 30000
}

# NGC 1569 - Membership in this group is uncertain.
Galaxy "@NGC 1569"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+1569"
	Type "E6"
	RA 4.513
	Dec 64.85
	Distance 7.5e6
	Radius 10000
}

# NGC 2366 - Membership in this group is uncertain.
Galaxy "@NGC 2366"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+2366"
	Type "Irr"
	RA 1.572
	Dec 69.217
	Distance 9.3e6
	Radius 20000
}

#############################################################################
#
#  Sculptor Group of galaxies
#

# NGC 253, Silver Coin Galaxy
Galaxy "@NGC 253"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+253"
	Type "SBa"
	RA 0.793
	Dec -25.283
	Distance 9.0e6
	Radius 50000
	Angle 110
}

# NGC 55
Galaxy "@NGC 55"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+55"
	Type "Sc"
	RA 0.248
	Dec -39.183
	Distance 7.0e6
	Radius 35000
}

# NGC 300
Galaxy "@NGC 300"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+300"
	Type "Sc"
	RA 0.915
	Dec -37.683
	Distance 1.0e7
	Radius 35000
}

# NGC 247
Galaxy "@NGC 247"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+247"
	Type "Sb"
	RA 0.785
	Dec -20.767
	Distance 7.0e6
	Radius 40000
	Angle 70
}

# NGC 7793
Galaxy "@NGC 7793"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+7793"
	Type "Sa"
	RA 23.963
	Dec -32.583
	Distance 9.0e6
	Radius 35000
}

# NGC 625
Galaxy "@NGC 625"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+625"
	Type "E7"
	RA 1.585
	Dec -41.433
	Distance 1.25e7
	Radius 30000
}

#############################################################################
#
#  NGC 5128 Group of galaxies
#

# NGC 5128, Centaurus A
Galaxy "@NGC 5128"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5128"
	Type "E0"
	RA 13.425
	Dec -43.0167
	Distance 1.3e7
	Radius 45000
}

# M83 / NGC 5236, Southern Pinwheel
Galaxy "@M83"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+83"
	Type "SBa"
	RA 13.617
	Dec -29.867
	Distance 1.5e7
	Radius 50000
}

# NGC 5253
Galaxy "@NGC 5253"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5253"
	Type "E6"
	RA 13.665
	Dec -31.65
	Distance 1.5e7
	Radius 30000
}

# NGC 4945
Galaxy "@NGC 4945"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4945"
	Type "Sb"
	RA 13.09
	Dec -49.467
	Distance 1.7e7
	Radius 50000
	Axis [ 0.712 0.533 0.456 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4945"
	Angle 100
}

# NGC 5102
Galaxy "@NGC 5102"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5102"
	Type "S0"
	RA 13.367
	Dec -36.633
	Distance 1.13e7
	Radius 30000
}

# NGC 5264
Galaxy "@NGC 5264"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5264"
	Type "Irr"
	RA 13.693
	Dec -29.917
	Distance 1.35e7
	Radius 10000
}

# NGC 5408
Galaxy "@NGC 5408"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5408"
	Type "Irr"
	RA 14.055
	Dec -41.383
	Distance 1.58e7
	Radius 20000
}

#############################################################################
#
#  NGC 1023 Group of galaxies
#

# NGC 891
Galaxy "@NGC 891"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+891"
	Type "Sb"
	RA 2.377
	Dec 42.35
	Distance 1.0e7
	Radius 50000
	Axis [ 0.712 0.533 0.456 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+891"
	Angle 100
}

# NGC 1023
Galaxy "@NGC 1023"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+1023"
	Type "Sb"
	RA 2.673
	Dec 39.067
	Distance 1.2e7
	Radius 50000
}

# NGC 925
Galaxy "@NGC 925"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+925"
	Type "SBc"
	RA 2.455
	Dec 33.583
	Distance 1.0e7
	Radius 50000
}

# NGC 949
Galaxy "@NGC 949"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+949"
	Type "E6"
	RA 2.513
	Dec 37.133
	Distance 1.0e7
	Radius 35000
}

# NGC 959
Galaxy "@NGC 959"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+959"
	Type "E4"
	RA 2.538
	Dec 35.5
	Distance 1.0e7
	Radius 30000
}

# NGC 1003
Galaxy "@NGC 1003"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+1003"
	Type "Sa"
	RA 2.725
	Dec 37.35
	Distance 1.3e7
	Radius 40000
}

# NGC 784, outlying member
Galaxy "@NGC 784"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+784"
	Type "Sc"
	RA 2.022
	Dec 28.833
	Distance 1.51e7
	Radius 20000
	Axis [ -0.596 -0.191 0.780 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+784"
	Angle 160
}

# UGC 1281, near NGC 784
Galaxy "@UGC 1281"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+1281"
	Type "Sd"
	RA 1.826
	Dec 32.58
	Distance 1.5e7
	Radius 15000
}

# NGC 404, outlying member?
Galaxy "@NGC 404"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+404"
	Type "E0"
	RA 1.157
	Dec 35.717
	Distance 7.7e6
	Radius 10000
}

#############################################################################
#
#  Leo Triplet of galaxies
#

# M65 / NGC 3623
Galaxy "@M65"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+65"
	Type "Sa"
	RA 11.315
	Dec 13.083
	Distance 3.5e7
	Radius 50000
}

# M66 / NGC 3627
Galaxy "@M66"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+66"
	Type "Sb"
	RA 11.337
	Dec 12.983
	Distance 3.5e7
	Radius 50000
}

# NGC 3628
Galaxy "@NGC 3628"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3628"
	Type "Sc"
	RA 11.338
	Dec 13.6
	Distance 3.5e7
	Radius 50000
	Axis [ -0.596 -0.191 0.780 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3628"
	Angle 100
}

#############################################################################
#
#  Leo I / M96 Group of galaxies
#

# M96 / NGC 3368
Galaxy "@M96"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+96"
	Type "Sa"
	RA 10.78
	Dec 11.817
	Distance 3.8e7
	Radius 50000
}

# M95 / NGC 3351
Galaxy "@M95"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+95"
	Type "SBb"
	RA 10.733
	Dec 11.7
	Distance 3.55e7
	Radius 50000
}

# M105 / NGC 3379
Galaxy "@M105"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+105"
	Type "E1"
	RA 10.797
	Dec 12.583
	Distance 3.8e7
	Radius 50000
}

# NGC 3377
Galaxy "@NGC 3377"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3377"
	Type "E5"
	RA 10.796
	Dec 13.99
	Distance 2.64e7
	Radius 30000
}

# NGC 3384
Galaxy "@NGC 3384"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3384"
	Type "S0"
	RA 10.804
	Dec 12.64
	Distance 2.64e7
	Radius 30000
}

# NGC 3239 / Arp 263
Galaxy "@NGC 3239"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3239"
	Type "Irr"
	RA 10.418
	Dec 17.16
	Distance 2.64e7
	Radius 30000
}

# NGC 3495
Galaxy "@NGC 3495"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3495"
	Type "Sd"
	RA 11.02
	Dec 3.61
	Distance 4.17e7
	Radius 30000
}

#############################################################################
#
#  M51-M101 Group of galaxies
#

# M51 /  NGC 5194
Galaxy "@M51"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+51"
	Type "Sc"
	RA 13.498
	Dec 47.2
	Distance 3.0e7
	Radius 45000
	Axis [ 0.712 0.533 0.456 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+51"
	Angle 195
}

# NGC 5195, interacting with M51
Galaxy "@NGC 5195"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5195"
	Type "E2"
	RA 13.5
	Dec 47.267
	Distance 3.0e7
	Radius 15000
	Axis [ 0.712 0.533 0.456 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5195"
	Angle 195
}

# M101 / NGC 5457
Galaxy "@M101"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+101"
	Type "Sb"
	RA 14.005
	Dec 54.35
	Distance 2.7e7
	Radius 70000
	Axis [ 0.712 0.533 0.456 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+101"
	Angle 195
}

# M63 / NGC 5055
Galaxy "@M63"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+63"
	Type "Sb"
	RA 13.263
	Dec 42.033
	Distance 2.3e7
	Radius 50000
}

# M106 / NGC 4258
Galaxy "@M106"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+106"
	Type "Sb"
	RA 12.317
	Dec 47.3
	Distance 2.3e7
	Radius 50000
}

# UGC 7774
Galaxy "@UGC 7774"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7774"
	Type "Sd"
	RA 12.605
	Dec 40.01
	Distance 2.22e7
	Radius 15000
}

# NGC 4248
Galaxy "@NGC 4248"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4248"
	Type "Irr"
	RA 12.298
	Dec 47.41
	Distance 2.38e7
	Radius 20000
}

# NGC 4242
Galaxy "@NGC 4242"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4242"
	Type "Sb"
	RA 12.29
	Dec 45.62
	Distance 2.45e7
	Radius 30000
}

# NGC 4618
Galaxy "@NGC 4618"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4618"
	Type "Sc"
	RA 12.693
	Dec 41.14
	Distance 2.38e7
	Radius 30000
}

# NGC 4625
Galaxy "@NGC 4625"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4625"
	Type "Irr"
	RA 12.698
	Dec 41.28
	Distance 2.67e7
	Radius 10000
}

# NGC 4490
Galaxy "@NGC 4490"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4490"
	Type "Sb"
	RA 12.512
	Dec 41.64
	Distance 3.0e7
	Radius 30000
}

# NGC 4485, companion to NGC 4490
Galaxy "@NGC 4485"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4485"
	Type "Irr"
	RA 12.51
	Dec 41.69
	Distance 3.03e7
	Radius 10000
}

# UGC 7719
Galaxy "@UGC 7719"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7719"
	Type "E7"
	RA 12.565
	Dec 39.01
	Distance 2.9e7
	Radius 10000
}

# UGC 7950
Galaxy "@UGC 7950"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7950"
	Type "Irr"
	RA 12.781
	Dec 51.64
	Distance 2.9e7
	Radius 10000
}

# UGC 8313
Galaxy "@UGC 8313"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+8313"
	Type "Sd"
	RA 13.23
	Dec 42.2
	Distance 3.0e7
	Radius 10000
}

# NGC 4288
Galaxy "@NGC 4288"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4288"
	Type "Irr"
	RA 12.344
	Dec 46.31
	Distance 2.61e7
	Radius 15000
}

# NGC 3985
Galaxy "@NGC 3985"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+3985"
	Type "Irr"
	RA 11.944
	Dec 48.32
	Distance 2.7e7
	Radius 10000
}

# NGC 4707
Galaxy "@NGC 4707"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4707"
	Type "Irr"
	RA 12.806
	Dec 51.16
	Distance 2.61e7
	Radius 10000
}

# NGC 4460
Galaxy "@NGC 4460"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4460"
	Type "S0"
	RA 12.48
	Dec 44.87
	Distance 2.64e7
	Radius 20000
}

# UGC 6900
Galaxy "@UGC 6900"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+6900"
	Type "Irr"
	RA 11.926
	Dec 31.54
	Distance 1.92e7
	Radius 10000
}

# UGC 7699
Galaxy "@UGC 7699"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7699"
	Type "Sd"
	RA 12.547
	Dec 37.62
	Distance 2.02e7
	Radius 15000
}

# UGC 7408
Galaxy "@UGC 7408"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7408"
	Type "Irr"
	RA 12.354
	Dec 45.82
	Distance 2.18e7
	Radius 10000
}

# UGC 7916
Galaxy "@UGC 7916"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7916"
	Type "Irr"
	RA 12.742
	Dec 34.39
	Distance 2.35e7
	Radius 10000
}

# UGC 7271
Galaxy "@UGC 7271"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7271"
	Type "Irr"
	RA 12.258
	Dec 43.42
	Distance 2.45e7
	Radius 10000
}

# UGC 7690
Galaxy "@UGC 7690"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7690"
	Type "Irr"
	RA 12.54
	Dec 42.71
	Distance 2.45e7
	Radius 10000
}

# UGC 7608
Galaxy "@UGC 7608"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7608"
	Type "Irr"
	RA 12.478
	Dec 43.22
	Distance 2.48e7
	Radius 15000
}

# UGC 7267
Galaxy "@UGC 7267"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7267"
	Type "E6"
	RA 12.256
	Dec 51.37
	Distance 2.54e7
	Radius 10000
}

# UGC 8683
Galaxy "@UGC 8683"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+8683"
	Type "Irr"
	RA 13.709
	Dec 39.67
	Distance 3.33e7
	Radius 15000
}

#############################################################################
#
#  M94 (CVn-I) group of galaxies
#

# M94 /  NGC 4736
Galaxy "@M94"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+94"
	Type "Sa"
	RA 12.848
	Dec 41.117
	Distance 1.38e7
	Radius 40000
}

# M64 / NGC 4826
Galaxy "@M64"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=M+64"
	Type "Sa"
	RA 12.945
	Dec 21.683
	Distance 1.9e7
	Radius 40000
}

# NGC 4455
Galaxy "@NGC 4455"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4455"
	Type "Sdm"
	RA 12.478
	Dec 22.82
	Distance 2.02e7
	Radius 10000
}

# NGC 5023
Galaxy "@NGC 5023"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5023"
	Type "Sc"
	RA 13.203
	Dec 44.033
	Distance 1.9e7
	Radius 45000
	Axis [ 0.712 0.533 0.456 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+5023"
	Angle 90
}

# UGC 7639
Galaxy "@UGC 7639"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+7639"
	Type "Irr"
	RA 12.498
	Dec 47.52
	Distance 1.89e7
	Radius 10000
}

# NGC 4244
Galaxy "@NGC 4244"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4244"
	Type "Sc"
	RA 12.292
	Dec 37.817
	Distance 9.9e6
	Radius 50000
	Axis [ -0.596 -0.191 0.780 ]
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4244"
	Angle 220
}

# NGC 4163
Galaxy "@NGC 4163"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4163"
	Type "E3"
	RA 12.203
	Dec 36.167
	Distance 6.75e6
	Radius 20000
}

# UGC 9128
Galaxy "@UGC 9128"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=UGC+9128"
	Type "Irr"
	RA 14.264
	Dec 23.05
	Distance 7.2e6
	Radius 10000
}

# NGC 4449
Galaxy "@NGC 4449"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4449"
	Type "Irr"
	RA   12.47
	Dec  44.1
	Distance 9.8e6
	Radius 15000
	Detail 0.5
}

# NGC 4190
Galaxy "@NGC 4190"
{
	InfoURL "http://simbad.u-strasbg.fr/sim-id.pl?Ident=NGC+4190"
	Type "E2"
	RA 12.228
	Dec 36.633
	Distance 9.0e6
	Radius 10000
}

# NGC 4214
G